from os import path
import json


def _load_icon_list():
    icon_list_path = path.join(path.dirname(__file__), "src", "icons.json")
    with open(icon_list_path, "r") as f:
        icon_list = json.load(f)
    return icon_list


def lavenderIcon(ext):
    icon_list = _load_icon_list()
    ext = ext.upper()
    if ext in icon_list:
        return icon_list[ext]
    else:
        return icon_list["DEFAULT"]

__all__ = ["lavenderIcon"]



from setuptools import setup, find_packages

setup(
    name="Lavender-Icon",
    version="1.0.1",
    description="A pip package for distributing file icons.",
    long_description=open(
        "README.md").read(),
    long_description_content_type="text/markdown",
    author="Zeyu Xie",
    author_email="xie.zeyu20@gmail.com",
    url="https://github.com/Zeyu-Xie/Lavender-Icon",
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
